==> itam-0.0.1.gem: app/models/itam/asset.rb <==
module Itam
  class Asset < ActiveRecord::Base

    belongs_to :asset_category
    belongs_to :status
    belongs_to :vendor
    belongs_to :employee
    belongs_to :department

    #---------------------------------------------------------------------------

    #attr_accessible

    #t.string :reference
    #t.string :asset_description
    #t.belongs_to :asset_category, index: true, foreign_key: true
    #t.belongs_to :status, index: true, foreign_key: true
    #t.belongs_to :vendor, index: true, foreign_key: true
    #t.belongs_to :employee, index: true, foreign_key: true
    #t.belongs_to :department, index: true, foreign_key: true
    #t.string :brand
    #t.string :model
    #t.string :model_number
    #t.string :serial_number
    #t.string :barcode_number
    #t.datetime :date_aquired
    #t.datetime :date_sold
    #t.decimal :purchase_price
    #t.string :deprication_method
    #t.float :depreciable_life
    #t.decimal :salvage_value
    #t.decimal :current_value
    #t.text :comments
    #t.text :description
    #t.datetime :next_scheduled_maintenance

    #---------------------------------------------------------------------------

    validates :reference, :asset_description, :presence => true
    validates :brand, :model, :model_number, :presence => true
    validates :serial_number, :barcode_number, :presence => true
    validates :deprication_method, :presence => true
    validates :comments, :description, :presence => true

    #---------------------------------------------------------------------------

    def to_s
      "#{reference} - #{asset_description}"
    end

  end
end

==> itam-0.1.0.gem: app/models/itam/asset.rb <==
module Itam
  class Asset < ActiveRecord::Base

    belongs_to :asset_category

    has_many :custom_attributes, :class_name => '::Itam::CustomAttribute', :foreign_key => 'asset_id'

    #---------------------------------------------------------------------------

    #attr_accessible

    #t.string :reference
    #t.string :asset_description
    #t.belongs_to :asset_category, index: true, foreign_key: true
    #t.belongs_to :status, index: true, foreign_key: true
    #t.belongs_to :vendor, index: true, foreign_key: true
    #t.belongs_to :employee, index: true, foreign_key: true
    #t.belongs_to :department, index: true, foreign_key: true
    #t.string :brand
    #t.string :model
    #t.string :model_number
    #t.string :serial_number
    #t.string :barcode_number
    #t.datetime :date_aquired
    #t.datetime :date_sold
    #t.decimal :purchase_price
    #t.string :deprication_method
    #t.float :depreciable_life
    #t.decimal :salvage_value
    #t.decimal :current_value
    #t.text :comments
    #t.text :description
    #t.datetime :next_scheduled_maintenance

    #---------------------------------------------------------------------------

    validates :reference, :asset_description, :presence => true
    validates :brand, :model, :model_number, :presence => true
    validates :serial_number, :barcode_number, :presence => true
    validates :deprication_method, :presence => true
    validates :comments, :description, :presence => true

    #---------------------------------------------------------------------------

    def to_s
      "#{reference} - #{asset_description} - (#{asset_category})"
    end

  end
end
